==> sentry-ones-0.1.3.tar.gz: sentry-ones-0.1.3/src/sentry_ones/finger_print.py <==
# coding: utf-8
from client import OnesClient
import hashlib

class Middleware:
    def __init__(self, config):
        self.client = OnesClient(config['email'], config['password'])
        self.assign = config['assign']
        self.summary = config['summary']
        self.project_uuid = config['project_uuid']
        self.issue_type_uuid = config.get('issue_type_uuid', 'LpALYBma')
        self.desc = config.get('desc', '')
        self.show_log = config['show_log']

    def generate_task_uuid(self, summary):
        # 确保 summary 是一个 Unicode 字符串
        if isinstance(summary, str):
            summary = summary.decode('utf-8')
        # Use SHA-256 hash and take the first 16 characters
        return hashlib.sha256(summary.encode('utf-8')).hexdigest()[:16]

    def run(self):
        task_uuid = self.generate_task_uuid(self.summary)
        self.client.login()
        if self.show_log:
            print('show_log:login success')
        # #搜索是否已存在
        task_info = self.client.search_task(task_uuid) 
        # print(task_info)
        if self.show_log:
            print('show_log: task_info has search')

        if task_info:
           #如果已经存在，检测一下存在的状态
          #  print(task_info,'task_info')
           if self.show_log:
            print('show_log: task_info is exist')
           task_status = task_info['status_uuid']
           if task_status != 'F3uKdez3':
               #更新ones单的状态为待开发
               self.client.update_task_init_status(task_info)
               #更新ones单的迭代为最近的迭代
               self.client.update_task_iteration(task_info)
        else:
          #如果不存在，则直接新建
          if self.show_log:
            print('show_log: task_info is not exist')
          create_response = self.client.create_task(task_uuid,self.assign, self.summary, self.project_uuid, self.issue_type_uuid, self.desc)
          print("Create Task Response:", create_response)

==> sentry-ones-0.1.9.tar.gz: sentry-ones-0.1.9/src/sentry_ones/finger_print.py <==
# coding: utf-8
from client import OnesClient
import hashlib

class Middleware:
    def __init__(self, config):
        self.client = OnesClient(config['email'], config['password'])
        self.assign = config['assign']
        self.summary = config['summary']
        self.project_uuid = config['project_uuid']
        self.issue_type_uuid = config.get('issue_type_uuid', 'LpALYBma')
        self.desc = config.get('desc', '')
        self.show_log = config['show_log']

    def generate_task_uuid(self, summary):
        # 确保 summary 是一个 Unicode 字符串
        if isinstance(summary, str):
            summary = summary.decode('utf-8')
        # Use SHA-256 hash and take the first 16 characters
        return hashlib.sha256(summary.encode('utf-8')).hexdigest()[:16]

    def run(self):
        task_uuid = self.generate_task_uuid(self.summary)
        self.client.login()
        if self.show_log == 'show':
            print('show_log:login success')
        # #搜索是否已存在
        task_info = self.client.search_task(task_uuid,self.show_log) 
        # print(task_info)
        if self.show_log == 'show':
            print('show_log: task_info has search')

        if task_info:
           #如果已经存在，检测一下存在的状态
          #  print(task_info,'task_info')
           if self.show_log == 'show':
            print('show_log: task_info is exist')
           task_status = task_info['status_uuid']
           if task_status != 'F3uKdez3':
               #更新ones单的状态为待开发
               self.client.update_task_init_status(task_info,self.show_log)
               #更新ones单的迭代为最近的迭代
               self.client.update_task_iteration(task_info,self.show_log)
        else:
          #如果不存在，则直接新建
          if self.show_log == 'show':
            print('show_log: task_info is not exist')
          self.client.create_task(task_uuid,self.assign, self.summary, self.project_uuid, self.issue_type_uuid, self.desc,self.show_log)
